package com.builttoroam.dual_screen

import android.app.Activity
import android.content.Context
import androidx.annotation.NonNull
import com.microsoft.device.display.DisplayMask
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

/** DualScreenPlugin */
public class DualScreenPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {
    // / The MethodChannel that will the communication between Flutter and native Android
    // /
    // / This local reference serves to register the plugin with the Flutter Engine and unregister it
    // / when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel
    private var applicationContext: Context? = null
    private var activity: Activity? = null

    lateinit var myplugin: DualScreenPlugin

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        myplugin = DualScreenPlugin()
        this.applicationContext = flutterPluginBinding.getApplicationContext()
        channel = MethodChannel(flutterPluginBinding.getBinaryMessenger(), "plugins.builttoroam.com/dual_screen")
        channel.setMethodCallHandler(this)
    }

    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "dual_screen")
            channel.setMethodCallHandler(DualScreenPlugin())
        }
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "isDualScreenDevice" -> {
                result.success(isDualScreenDevice())
            }
            "isAppSpanned" -> {
                if (isDualScreenDevice()) {
                    result.success(isAppSpanned())
                } else {
                    result.success(false)
                }
            }
            else -> {
                result.notImplemented()
            }
        }
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        myplugin.activity = binding.activity;
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        myplugin.activity = binding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
        TODO("not implemented")
    }

    override fun onDetachedFromActivity() {
        TODO("not implemented")
    }

    fun isDualScreenDevice(): Boolean {
        return applicationContext?.getPackageManager()!!.hasSystemFeature("com.microsoft.device.display.displaymask")
    }

    fun isAppSpanned(): Boolean {
//        var drawingRect = android.graphics.Rect()
//        activity?.getWindow()?.getDecorView()?.getRootView()?.getDrawingRect(drawingRect)
//        return DisplayMask.fromResourcesRectApproximation(applicationContext).getBoundingRects().get(0)
//            .intersect(drawingRect)
        var boundings = DisplayMask.fromResourcesRectApproximation(myplugin.activity)
            .getBoundingRects()
        var first = boundings.get(0)
        var rootView = activity?.getWindow()?.getDecorView()?.getRootView()
        var drawingRect = android.graphics.Rect()
        rootView?.getDrawingRect(drawingRect)
        return first.intersect(drawingRect)
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        applicationContext = null
        channel.setMethodCallHandler(null)
    }
}
